import { NetworkType } from 'symbol-sdk';
import { Preset } from '../service';
import { NodeType } from './NodeType';
export declare enum PrivateKeySecurityMode {
    ENCRYPT = "ENCRYPT",
    PROMPT_MAIN = "PROMPT_MAIN",
    PROMPT_MAIN_VOTING = "PROMPT_MAIN_VOTING",
    PROMPT_ALL = "PROMPT_ALL"
}
export interface DockerServicePreset {
    ipv4_address?: string;
    openPort?: boolean | number | string;
    host?: string;
    excludeDockerService?: boolean;
    environment?: any;
    compose?: any;
    dockerComposeDebugMode?: boolean;
}
export interface MosaicPreset {
    name: string;
    repeat?: number;
    main: boolean;
    harvest: boolean;
    divisibility: number;
    duration: number;
    supply: number;
    isTransferable: boolean;
    isSupplyMutable: boolean;
    isRestrictable: boolean;
    accounts: number;
    currencyDistributions: {
        address: string;
        amount: number;
    }[];
}
export interface DatabasePreset extends DockerServicePreset {
    repeat?: number;
    name: string;
    databaseName?: string;
}
export interface NemesisPreset {
    binDirectory: string;
    mosaics?: MosaicPreset[];
    balances?: Record<string, number>;
    transactions?: Record<string, string>;
    nemesisSignerPrivateKey: string;
    transactionsDirectory: string;
}
export interface NodePreset extends DockerServicePreset {
    serverVersion?: string;
    nodeUseRemoteAccount?: boolean;
    repeat?: number;
    harvesting: boolean;
    api: boolean;
    voting: boolean;
    databaseHost: string;
    host?: string;
    name: string;
    roles: string;
    friendlyName?: string;
    mainPrivateKey?: string;
    mainPublicKey?: string;
    transportPrivateKey?: string;
    transportPublicKey?: string;
    remotePrivateKey?: string;
    remotePublicKey?: string;
    vrfPrivateKey?: string;
    vrfPublicKey?: string;
    votingPrivateKey?: string;
    votingPublicKey?: string;
    brokerName?: string;
    brokerHost?: string;
    brokerIpv4_address?: string;
    brokerOpenPort?: boolean | number | string;
    brokerExcludeDockerService?: boolean;
    brokerCompose?: any;
    brokerDockerComposeDebugMode?: boolean;
    rewardProgram?: string;
    rewardProgramAgentIpv4_address?: string;
    rewardProgramAgentOpenPort?: boolean | number | string;
    rewardProgramAgentExcludeDockerService?: boolean;
    rewardProgramAgentCompose?: any;
    rewardProgramAgentHost?: string;
    rewardProgramAgentDockerComposeDebugMode?: boolean;
    agentUrl?: string;
    restGatewayUrl?: string;
}
export interface GatewayPreset extends DockerServicePreset {
    repeat?: number;
    apiNodeName: string;
    apiNodeHost: string;
    databaseHost: string;
    name: string;
}
export interface ExplorerPreset extends DockerServicePreset {
    repeat?: number;
    name: string;
}
export interface WalletProfilePreset {
    name: number;
    data?: any;
    location?: string;
}
export interface WalletPreset extends DockerServicePreset {
    repeat?: number;
    name: string;
    profiles?: WalletProfilePreset[];
}
export interface FaucetPreset extends DockerServicePreset {
    gateway: string;
    repeat?: number;
    name: string;
}
export interface ConfigPreset {
    preset: Preset;
    privateKeySecurityMode: string;
    votingKeysDirectory: string;
    serverVersion: string;
    sinkAddress?: string;
    epochAdjustment: string;
    catapultAppFolder: string;
    dataDirectory: string;
    subnet?: string;
    transactionsDirectory: string;
    faucetUrl?: string;
    nemesis?: NemesisPreset;
    nemesisSeedFolder?: string;
    assemblies?: string;
    databaseName: string;
    nemesisSignerPublicKey: string;
    nemesisGenerationHashSeed: string;
    harvestNetworkFeeSinkAddress?: string;
    mosaicRentalFeeSinkAddress?: string;
    namespaceRentalFeeSinkAddress?: string;
    nodeUseRemoteAccount: boolean;
    networkheight: boolean;
    dockerComposeVersion: number | string;
    dockerComposeServiceRestart: string;
    dockerComposeDebugMode: boolean;
    nodes?: NodePreset[];
    gateways?: GatewayPreset[];
    explorers?: ExplorerPreset[];
    wallets?: WalletPreset[];
    faucets?: FaucetPreset[];
    networkType: NetworkType;
    networkIdentifier: string;
    networkName: string;
    currencyMosaicId: string;
    harvestingMosaicId: string;
    baseNamespace: string;
    databases?: DatabasePreset[];
    knownPeers?: Record<NodeType, any[]>;
    knownRestGateways?: string[];
    mongoComposeRunParam: string;
    mongoImage: string;
    symbolServerToolsImage: string;
    symbolExplorerImage: string;
    symbolWalletImage: string;
    symbolFaucetImage: string;
    symbolServerImage: string;
    symbolAgentImage: string;
    symbolRestImage: string;
    votingKeyStartEpoch: number;
    votingKeyEndEpoch: number;
    rewardProgramControllerPublicKey?: string;
    votingKeyLinkV2: number | undefined;
}
